# Security policy


## Supported versions

Only the latest version of `redflag` is supported.


## Reporting a vulnerability

Please do not report on issue on GitHub, instead report vulnerabilities to hello@scienxlab.org

We do not award bounties for security vulnerabilities, but will notify you if and when the report is accepted and acted upon.
